@@ -263,7 +263,7 @@ void
 about(GtkWidget *widget, gpointer data)
 {
         GtkWidget *about;
-        gchar *authors[] = {
+        const gchar *authors[] = {
 		"Code: Pista",
 		"Faces: tigert",
 		"Score: HoraPe",
@@ -272,7 +272,7 @@ about(GtkWidget *widget, gpointer data)
 
         about = gnome_about_new (_("Gnome Mines"), VERSION,
 				 "(C) 1997-1998 the Free Software Fundation",
-				 authors,
+				 (const char **)authors,
 				 _("Minesweeper clone"),
 				 NULL);
         gtk_widget_show (about);
@@ -361,8 +361,14 @@ void setup_game(GtkWidget *widget, gpointer data)
         adj = gtk_adjustment_new(minesize, 2, 99, 1, 5, 10);
 	sentry = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 10, 0);
         gtk_spin_button_set_update_policy(GTK_SPIN_BUTTON(sentry),
-					  GTK_UPDATE_ALWAYS |
-					  GTK_UPDATE_SNAP_TO_TICKS);
+					  GTK_UPDATE_ALWAYS
+#ifndef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
+					  | GTK_UPDATE_SNAP_TO_TICKS
+#endif
+					  );
+#ifdef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
+	gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(sentry), 1);
+#endif
         gtk_box_pack_start(GTK_BOX(box2), sentry, FALSE, TRUE, 0);
 	gtk_widget_show(sentry);
 	gtk_widget_show(box2);
